@@ -59,7 +59,7 @@ my $source_packs = [
   {
     title   => "Source code build: SDL-1.2.14 & co. (RECOMMENDED)\n" .
                "\tbuilds: SDL, SDL_(image|mixer|ttf|net|gfx|Pango)\n" .
-               "\tneeds preinstalled: (freetype2|pango)-devel\n",
+               "\tneeds preinstalled: (freetype2|pango)-devel",
     prereqs => {
         libs => [
           'pthread', # SDL
@@ -112,7 +112,7 @@ my $source_packs = [
         pack => 'png',
         dirname => 'libpng-1.4.1',
         url => [
-          'http://downloads.sourceforge.net/libpng/libpng-1.4.1.tar.gz',
+          'http://downloads.sourceforge.net/project/libpng/01-libpng-master/1.4.1/libpng-1.4.1.tar.gz',
           'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
         ],
         sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
@@ -182,6 +182,96 @@ my $source_packs = [
       },
     ],
   },
+## another src set - builds just SDL+ SDL_* libs, all other prereq libs needs to be installed 
+  {
+    title   => "Source code build: SDL-1.2.14 & co. (builds only SDL+SDL_*)\n" .
+               "\tbuilds: SDL, SDL_(image|mixer|ttf|net|gfx|Pango)\n" .
+               "\tneeds preinstalled: all non-SDL libs",
+    prereqs => {
+        libs => [
+          'pthread', # SDL
+	  'z', 'jpeg', 'tiff', 'png',
+          'pangoft2', 'pango', 'gobject', 'gmodule', 'glib', 'fontconfig', 'freetype', 'expat', # SDL_Pango
+        ]
+    },
+    members     => [
+      {
+        pack => 'SDL',
+        dirname => 'SDL-1.2.14',
+        url => [
+          'http://www.libsdl.org/release/SDL-1.2.14.tar.gz',
+          'http://froggs.de/libsdl/SDL-1.2.14.tar.gz',
+        ],
+        sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
+        patches => [
+          'test1.patch',
+        ],
+      },
+      {
+        pack => 'SDL_image',
+        dirname => 'SDL_image-1.2.10',
+        url => [
+          'http://www.libsdl.org/projects/SDL_image/release/SDL_image-1.2.10.tar.gz',
+          'http://froggs.de/libsdl/SDL_image-1.2.10.tar.gz',
+        ],
+        sha1sum  => '6bae71fdfd795c3dbf39f6c7c0cf8b212914ef97',
+        patches => [ ],
+      },
+      {
+        pack => 'SDL_mixer',
+        dirname => 'SDL_mixer-1.2.11',
+        url => [
+          'http://www.libsdl.org/projects/SDL_mixer/release/SDL_mixer-1.2.11.tar.gz',
+          'http://froggs.de/libsdl/SDL_mixer-1.2.11.tar.gz',
+        ],
+        sha1sum  => 'ef5d45160babeb51eafa7e4019cec38324ee1a5d',
+        patches => [ ],
+      },
+      {
+        pack => 'SDL_ttf',
+        dirname => 'SDL_ttf-2.0.10',
+        url => [
+          'http://www.libsdl.org/projects/SDL_ttf/release/SDL_ttf-2.0.10.tar.gz',
+          'http://froggs.de/libsdl/SDL_ttf-2.0.10.tar.gz',
+        ],
+        sha1sum  => '98f6518ec71d94b8ad303a197445e0991850b887',
+        patches => [ ],
+      },
+      {
+        pack => 'SDL_net',
+        dirname => 'SDL_net-1.2.7',
+        url => [
+          'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
+          'http://froggs.de/libsdl/SDL_net-1.2.7.tar.gz',
+        ],
+        sha1sum  => 'b46c7e3221621cc34fec1238f1b5f0ce8972274d',
+        patches => [ ],
+      },
+      {
+        pack => 'SDL_gfx',
+        dirname => 'SDL_gfx-2.0.20',
+        url => [
+          'http://www.ferzkopp.net/Software/SDL_gfx-2.0/SDL_gfx-2.0.20.tar.gz',
+          'http://froggs.de/libsdl/SDL_gfx-2.0.20.tar.gz',
+        ],
+        sha1sum  => '077f7e64376c50a424ef11a27de2aea83bda3f78',
+        patches => [ ],
+      },
+      {
+        pack => 'SDL_Pango',
+        dirname => 'SDL_Pango-0.1.2',
+        url => [
+          'http://downloads.sourceforge.net/sdlpango/SDL_Pango-0.1.2.tar.gz',
+          'http://froggs.de/libsdl/SDL_Pango-0.1.2.tar.gz',
+        ],
+        sha1sum  => 'c30f2941d476d9362850a150d29cb4a93730af68',
+        patches => [
+          'SDL_Pango-0.1.2-API-adds.1.patch',
+          'SDL_Pango-0.1.2-API-adds.2.patch',
+        ],
+      },
+    ],
+  },
 ## another src build set (without PANGO SUPPORT)
   {
     title   => "Source code build: SDL-1.2.14 & co. (no PANGO, but TTF)\n" .
@@ -239,7 +329,7 @@ my $source_packs = [
         pack => 'png',
         dirname => 'libpng-1.4.1',
         url => [
-          'http://downloads.sourceforge.net/libpng/libpng-1.4.1.tar.gz',
+          'http://downloads.sourceforge.net/project/libpng/01-libpng-master/1.4.1/libpng-1.4.1.tar.gz',
           'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
         ],
         sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
@@ -351,7 +441,7 @@ my $source_packs = [
         pack => 'png',
         dirname => 'libpng-1.4.1',
         url => [
-          'http://downloads.sourceforge.net/libpng/libpng-1.4.1.tar.gz',
+          'http://downloads.sourceforge.net/project/libpng/01-libpng-master/1.4.1/libpng-1.4.1.tar.gz',
           'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
         ],
         sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
@@ -441,7 +531,7 @@ my $source_packs = [
         pack => 'png',
         dirname => 'libpng-1.4.1',
         url => [
-          'http://downloads.sourceforge.net/libpng/libpng-1.4.1.tar.gz',
+          'http://downloads.sourceforge.net/project/libpng/01-libpng-master/1.4.1/libpng-1.4.1.tar.gz',
           'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
         ],
         sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
@@ -566,7 +656,7 @@ sub check_src_build
   my @good = ();
   foreach my $p (@{$source_packs}) {
     $p->{buildtype} = 'build_from_sources';
-    print "CHECKING prereqs for:\n\t$p->{title}";
+    print "CHECKING prereqs for:\n\t$p->{title}\n";
     push @good, $p if check_prereqs($p);
   }
   return \@good;
@@ -589,6 +679,12 @@ sub check_prereqs_libs {
 	$inc_lib_candidates->{'/usr/include'} = '/usr/lib64'
     }
 
+    if ( exists $ENV{SDL_LIB} && exists $ENV{SDL_INC} )
+    {
+	$inc_lib_candidates->{$ENV{SDL_INC}} = $ENV{SDL_LIB};
+    }
+
+
     my $header_map         = {
       'z'    => 'zlib',
       'jpeg' => 'jpeglib',
@@ -599,7 +695,7 @@ sub check_prereqs_libs {
     foreach (keys %$inc_lib_candidates) {
       my $ld = $inc_lib_candidates->{$_};
       next unless -d $_ && -d $ld;
-      ($found_lib) = find_file($ld, qr/[\/\\]lib\Q$lib\E[\-\d\.]*\.($dlext[\d\.]*|a)$/);
+      ($found_lib) = find_file($ld, qr/[\/\\]lib\Q$lib\E[\-\d\.]*\.($dlext[\d\.]*|a|dll.a)$/);
       ($found_inc) = find_file($_,  qr/[\/\\]\Q$header\E[\-\d\.]*\.h$/);
       last if $found_lib && $found_inc;
     }
@@ -608,7 +704,10 @@ sub check_prereqs_libs {
       $ret &= 1;
     }
     else {
-      print "WARNING: required lib(-dev) '$lib' not found, disabling affected option\n";
+      my $reason = 'no-h+no-lib';
+      $reason = 'no-lib' if !$found_lib && $found_inc;
+      $reason = 'no-h' if $found_lib && !$found_inc;
+      print "WARNING: required lib(-dev) '$lib' not found, disabling affected option ($reason)\n";
       $ret = 0;
     }
   }
@@ -727,6 +826,11 @@ sub get_dlext {
   if($^O =~ /darwin/) { # there can be .dylib's on a mac even if $Config{dlext} is 'bundle'
     return 'so|dylib|bundle';
   }
+  elsif( $^O =~ /cygwin/)
+  {  
+    warn 'USING la for cygwin';
+    return 'la';
+  }
   else {
     return $Config{dlext};
   }
